@@ -49,58 +49,16 @@ hmo_sax <- function(a, w, qtd) {
 #'@importFrom dplyr desc
 #'@export
 detect.hmo_sax <- function(obj, serie, ...) {
-  binning_sax <- function(v, a) {
-    p <- base::seq(from = 0, to = 1, by = 1/a)
-    q <- stats::quantile(v, p)
-    qf <- base::matrix(c(q[1:(length(q)-1)],q[2:(length(q))]), ncol=2)
-    vp <- base::cut(v, unique(q), FALSE, include.lowest=TRUE)
-    m <- base::tapply(v, vp, mean)
-    vm <- m[vp]
-    mse <- base::mean((v - vm)^2, na.rm = TRUE)
-    return (list(binning=m, bins_factor=vp, q=q, qf=qf, bins=vm, mse=mse))
-  }
-
-  convert_to_sax <- function(num, nbase) {
-    chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-    if(nbase < 2 || nbase > stringr::str_length(chars))
-      return("")
-    newNumber <- ""
-    r <- 0
-    while(num >= nbase)
-    {
-      r <- num %% nbase
-      newNumber <- base::sprintf("%s%s", substr(chars, r+1, r+1), newNumber)
-      num <- as.integer(num / nbase)
-    }
-    newNumber = base::sprintf("%s%s", substr(chars, num+1, num+1), newNumber)
-    return (newNumber)
-  }
-
-  convert_to_sax_vec <- function(num, nbase) {
-    n <- length(num)
-    result <- rep("", n)
-    for (i in 1:n) {
-      result[i] <- convert_to_sax(num[i], nbase)
-    }
-    return(result)
-  }
-
-  norm_sax <- function (vector, slices)
-  {
-    vectorNorm <- (vector - base::mean(vector, na.rm = T))/stats::sd(vector, na.rm = T)
-    mybin <- binning_sax(vectorNorm, slices)
-    i <- base::ceiling(log(slices, 26))
-    mycode <- stringr::str_pad(convert_to_sax_vec(0:(slices-1), 26), i, pad="0")
-    saxvector <- mycode[mybin$bins_factor]
-    return(saxvector)
-  }
   i <- 0
   total_count <- 0
   if(is.null(serie)) stop("No data was provided for computation", call. = FALSE)
 
   obj <- obj$har_store_refs(obj, serie)
 
-  tss <- norm_sax(obj$serie, obj$a)
+  tsax <- trans_sax(obj$a)
+  tsax <- fit(tsax, obj$serie)
+  tss <- transform(tsax, obj$serie)
+
   tsw <- daltoolbox::ts_data(tss, obj$w)
   seq <- base::apply(tsw, MARGIN = 1, function(x) paste(as.vector(x), collapse=""))
   data <- data.frame(i = 1:nrow(tsw), seq)
